<?php
// index.php 主框架页面
session_start();
require_once 'database_config.php';

// 检查用户是否已登录，未登录则重定向到登录页面
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit;
}

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <style>
        /* 基础样式 */
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Microsoft YaHei', Tahoma, Geneva, Verdana, sans-serif;
            background: #f0f2f5;
        }

        /* 侧边栏容器 */
        .sidebar {
            position: fixed;
            left: 0;
            top: 0;
            width: 200px;
            height: 100vh;
            background: #2c3e50;
            padding: 20px 0;
            box-shadow: 2px 0 5px rgba(0, 0, 0, 0.1);
            z-index: 100;
            overflow-y: auto;
        }

        /* 侧边栏导航 */
        .nav-menu {
            list-style: none;
        }

        .nav-item {
            margin: 5px 15px;
        }

        .nav-link {
            display: block;
            padding: 10px 15px;
            color: #ffffff !important;
            text-decoration: none;
            border-radius: 4px;
            transition: all 0.3s;
            font-size: 14px;
        }

        .nav-link:hover {
            background: #34495e;
            color: #ecf0f1;
        }

        /* 返回按钮样式 */
        .back-btn {
            background: #3498db;
            margin-bottom: 20px;
        }

        .back-btn:hover {
            background: #2980b9;
        }

        /* 折叠菜单 */
        .submenu {
            list-style: none;
            margin-left: 15px;
            display: none;
        }

        .nav-item.active .submenu {
            display: block;
        }

        .nav-item.active>a {
            background: #4CAF50;
            color: white !important;
        }

        .submenu .nav-link {
            padding: 8px 15px;
            font-size: 13px;
        }

        /* 选中状态样式 */
        .nav-link.selected {
            background: #4CAF50;
            color: white !important;
        }

        .submenu .nav-link.selected {
            background: #388E3C;
            color: white !important;
        }

        /* 右侧内容区 */
        .content-frame {
            margin-left: 200px;
            height: 100vh;
        }

        iframe {
            width: 100%;
            height: 100%;
            border: none;
            background: #fff;
        }

        /* 用户信息 */
        .user-info {
            color: #fff;
            padding: 10px 20px;
            margin-bottom: 20px;
            border-bottom: 1px solid #34495e;
            font-size: 14px;
        }

        /* 系统标题样式 */
        .main-title {
            text-align: center;
            background-color: #4CAF50;
            padding: 10px 0;
            margin-bottom: 0;
            border-bottom: 1px solid #e0e0e0;
        }

        .main-title h1 {
            margin: 0;
            color: #ffffff;
            font-size: 24px;
            font-weight: normal;
        }

        /* 页脚样式 */
        .main-footer {
            text-align: center;
            background-color: #f5f5f5;
            color: #333;
            padding: 5px 0;
            position: fixed;
            bottom: 0;
            width: calc(100% - 200px);
            margin-left: 0;
            font-size: 10px;
            border-top: 1px solid #e0e0e0;
        }
    </style>
</head>

<body>
    <!-- 侧边栏 -->
    <nav class="sidebar">
        <div class="user-info">
            用户: <?php echo htmlspecialchars($_SESSION['username']); ?>
        </div>
        <ul class="nav-menu">
            <li class="nav-item">
                <a href="logout.php" class="nav-link back-btn">
                    退出登录
                </a>
            </li>

            <!-- 1. 用户与权限管理 -->
            <?php if (has_permission('system')): ?>
                <li class="nav-item" data-module="system">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('system/index.php', 'system')">
                        用户与权限管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="user" onclick="loadPage('system/user.php', 'system', 'user')">用户管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="role" onclick="loadPage('system/role.php', 'system', 'role')">角色权限管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="log" onclick="loadPage('system/log.php', 'system', 'log')">操作日志</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="backup" onclick="loadPage('system/backup.php', 'system', 'backup')">数据备份</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 2. 客户管理 -->
            <?php if (has_permission('client')): ?>
                <li class="nav-item" data-module="client">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('client/index.php', 'client')">
                        客户管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="profile" onclick="loadPage('client/profile.php', 'client', 'profile')">客户档案</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="contact" onclick="loadPage('client/contact.php', 'client', 'contact')">联系人管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="relation" onclick="loadPage('client/relation.php', 'client', 'relation')">客户关系维护</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="reminder" onclick="loadPage('client/reminder.php', 'client', 'reminder')">客户提醒</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 3. 销售管理 -->
            <?php if (has_permission('sales')): ?>
                <li class="nav-item" data-module="sales">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('sales/index.php', 'sales')">
                        销售管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="chance" onclick="loadPage('sales/chance.php', 'sales', 'chance')">销售机会管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="clue" onclick="loadPage('sales/clue.php', 'sales', 'clue')">销售线索管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="track" onclick="loadPage('sales/track.php', 'sales', 'track')">销售过程跟踪</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="contract" onclick="loadPage('sales/contract.php', 'sales', 'contract')">合同管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="quote" onclick="loadPage('sales/quote.php', 'sales', 'quote')">报价管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="target" onclick="loadPage('sales/target.php', 'sales', 'target')">销售目标与绩效</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 4. 订单管理 -->
            <?php if (has_permission('order')): ?>
                <li class="nav-item" data-module="order">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('order/index.php', 'order')">
                        订单管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="entry" onclick="loadPage('order/entry.php', 'order', 'entry')">订单录入</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="review" onclick="loadPage('order/review.php', 'order', 'review')">订单审核</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="status" onclick="loadPage('order/status.php', 'order', 'status')">订单状态管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="invoice" onclick="loadPage('order/invoice.php', 'order', 'invoice')">发票管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="refund" onclick="loadPage('order/refund.php', 'order', 'refund')">退款与退货</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 5. 市场营销管理 -->
            <?php if (has_permission('marketing')): ?>
                <li class="nav-item" data-module="marketing">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('marketing/index.php', 'marketing')">
                        市场营销管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="activity" onclick="loadPage('marketing/activity.php', 'marketing', 'activity')">营销活动管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="email" onclick="loadPage('marketing/email.php', 'marketing', 'email')">邮件和短信营销</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="ad" onclick="loadPage('marketing/ad.php', 'marketing', 'ad')">广告投放管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="analysis" onclick="loadPage('marketing/analysis.php', 'marketing', 'analysis')">营销数据分析</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 6. 客户服务与售后 -->
            <?php if (has_permission('service')): ?>
                <li class="nav-item" data-module="service">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('service/index.php', 'service')">
                        客户服务与售后
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="ticket" onclick="loadPage('service/ticket.php', 'service', 'ticket')">工单管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="feedback" onclick="loadPage('service/feedback.php', 'service', 'feedback')">客户反馈管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="knowledge" onclick="loadPage('service/knowledge.php', 'service', 'knowledge')">知识库</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="follow" onclick="loadPage('service/follow.php', 'service', 'follow')">售后跟进</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="survey" onclick="loadPage('service/survey.php', 'service', 'survey')">满意度调查</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 7. 产品与库存管理 -->
            <?php if (has_permission('product')): ?>
                <li class="nav-item" data-module="product">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('product/index.php', 'product')">
                        产品与库存管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="catalog" onclick="loadPage('product/catalog.php', 'product', 'catalog')">产品目录</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="inventory" onclick="loadPage('product/inventory.php', 'product', 'inventory')">库存管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="supplier" onclick="loadPage('product/supplier.php', 'product', 'supplier')">供应商管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="price" onclick="loadPage('product/price.php', 'product', 'price')">价格策略</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="analysis" onclick="loadPage('product/analysis.php', 'product', 'analysis')">产品销售分析</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 8. 财务管理 -->
            <?php if (has_permission('finance')): ?>
                <li class="nav-item" data-module="finance">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('finance/index.php', 'finance')">
                        财务管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="receipt" onclick="loadPage('finance/receipt.php', 'finance', 'receipt')">收款管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="payment" onclick="loadPage('finance/payment.php', 'finance', 'payment')">付款审核</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="commission" onclick="loadPage('finance/commission.php', 'finance', 'commission')">佣金管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="budget" onclick="loadPage('finance/budget.php', 'finance', 'budget')">预算与成本管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="reconcile" onclick="loadPage('finance/reconcile.php', 'finance', 'reconcile')">对账管理</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 9. 数据分析与报表 -->
            <?php if (has_permission('report')): ?>
                <li class="nav-item" data-module="report">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('report/index.php', 'report')">
                        数据分析与报表
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="client" onclick="loadPage('report/client.php', 'report', 'client')">客户增长分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="sales" onclick="loadPage('report/sales.php', 'report', 'sales')">销售业绩分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="marketing" onclick="loadPage('report/marketing.php', 'report', 'marketing')">市场营销数据</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="satisfaction" onclick="loadPage('report/satisfaction.php', 'report', 'satisfaction')">客户满意度分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="finance" onclick="loadPage('report/finance.php', 'report', 'finance')">财务数据分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="custom" onclick="loadPage('report/custom.php', 'report', 'custom')">自定义报表</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 10. 任务与日程管理 -->
            <?php if (has_permission('task')): ?>
                <li class="nav-item" data-module="task">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('task/index.php', 'task')">
                        任务与日程管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="todo" onclick="loadPage('task/todo.php', 'task', 'todo')">待办事项</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="schedule" onclick="loadPage('task/schedule.php', 'task', 'schedule')">日程安排</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="notify" onclick="loadPage('task/notify.php', 'task', 'notify')">提醒通知</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="team" onclick="loadPage('task/team.php', 'task', 'team')">团队协作</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 11. 人员绩效与KPI -->
            <?php if (has_permission('performance')): ?>
                <li class="nav-item" data-module="performance">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('performance/index.php', 'performance')">
                        人员绩效与KPI
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="target" onclick="loadPage('performance/target.php', 'performance', 'target')">销售目标设定</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="assess" onclick="loadPage('performance/assess.php', 'performance', 'assess')">业绩考核</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="incentive" onclick="loadPage('performance/incentive.php', 'performance', 'incentive')">激励机制</a></li>
                    </ul>
                </li>
            <?php endif; ?>

        </ul>
    </nav>

    <!-- 右侧内容区 -->
    <div class="content-frame">
        <div class="main-title">
            <h1><?php echo title; ?></h1>
        </div>

        <?php if (isset($_GET['error']) && $_GET['error'] == 'no_permission'): ?>
            <div style="background-color: #f8d7da; color: #721c24; padding: 10px; margin: 10px; border-radius: 4px; text-align: center;">
                <p>您没有权限访问此页面，请联系管理员获取相应权限。</p>
            </div>
        <?php endif; ?>

        <iframe name="contentFrame" id="mainFrame" src="system/index.php"></iframe>
        <div class="main-footer">
            版权所有 &copy; <?php echo date('Y'); ?> <?php echo title; ?>
        </div>
    </div>

    <script>
        // 当前选中的模块和页面
        let currentModule = 'system';
        let currentPage = '';

        // 页面加载函数
        function loadPage(pageUrl, module, page = '') {
            document.getElementById('mainFrame').src = pageUrl;

            // 更新当前选中的模块和页面
            currentModule = module;
            currentPage = page;

            // 更新菜单选中状态
            updateMenuSelection();
        }

        // 更新菜单选中状态
        function updateMenuSelection() {
            // 清除所有选中状态
            const allLinks = document.querySelectorAll('.nav-link');
            allLinks.forEach(link => {
                link.classList.remove('selected');
            });

            // 设置当前模块的选中状态
            const moduleItem = document.querySelector(`.nav-item[data-module="${currentModule}"]`);
            if (moduleItem) {
                const moduleLink = moduleItem.querySelector(':scope > a');
                moduleLink.classList.add('selected');

                // 如果有子页面，设置子页面的选中状态
                if (currentPage) {
                    const pageLink = moduleItem.querySelector(`.submenu .nav-link[data-page="${currentPage}"]`);
                    if (pageLink) {
                        pageLink.classList.add('selected');
                    }
                }
            }
        }

        // 切换子菜单显示/隐藏
        function toggleSubmenu(item) {
            // 先关闭所有已打开的子菜单
            const allItems = document.querySelectorAll('.nav-item');
            allItems.forEach(el => {
                if (el !== item && el.classList.contains('active')) {
                    el.classList.remove('active');
                }
            });

            // 切换当前项的active状态
            item.classList.toggle('active');

            // 更新菜单选中状态
            updateMenuSelection();
        }

        // 初始化加载默认页
        window.onload = function() {
            loadPage('system/index.php', 'system');

            // 默认展开第一个可访问的菜单
            const menuItems = document.querySelectorAll('.nav-item[data-module]');
            if (menuItems.length > 0) {
                // 找到第一个可见的菜单项
                let firstVisibleItem = null;
                menuItems.forEach(item => {
                    if (item.offsetParent !== null && !firstVisibleItem) {
                        firstVisibleItem = item;
                    }
                });

                if (firstVisibleItem) {
                    firstVisibleItem.classList.add('active');
                }
            }
        }
    </script>

</body>

</html>