<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('order_entry');

// 记录访问日志
record_log('访问订单录入页面');

// 添加/编辑/删除订单处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加订单
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $contract_id = isset($_POST['contract_id']) && $_POST['contract_id'] > 0 ? intval($_POST['contract_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_method = isset($_POST['payment_method']) ? trim($_POST['payment_method']) : '';
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $creator_id = $_SESSION['user_id'];

        if ($client_id <= 0 || $amount <= 0) {
            $error = '请填写完整订单信息！';
        } else {
            try {
                // 生成订单编号
                $order_no = 'DD-' . date('Ymd') . '-' . str_pad(rand(1, 999), 3, '0', STR_PAD_LEFT);

                // 检查订单编号是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM order_orders WHERE order_no = ?");
                $stmt->execute([$order_no]);
                $result = $stmt->fetch();

                // 如果存在，重新生成
                while ($result['count'] > 0) {
                    $order_no = 'DD-' . date('Ymd') . '-' . str_pad(rand(1, 999), 3, '0', STR_PAD_LEFT);
                    $stmt->execute([$order_no]);
                    $result = $stmt->fetch();
                }

                // 添加订单
                $stmt = $pdo->prepare("INSERT INTO order_orders (order_no, client_id, contract_id, amount, status, payment_method, remark, creator_id) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$order_no, $client_id, $contract_id, $amount, $status, $payment_method, $remark, $creator_id]);

                if ($result) {
                    record_log("添加订单：{$order_no}");
                    $success = '订单添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: entry.php?success=add');
                    exit;
                } else {
                    $error = '订单添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑订单
    elseif ($_POST['action'] == 'edit') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $contract_id = isset($_POST['contract_id']) && $_POST['contract_id'] > 0 ? intval($_POST['contract_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_method = isset($_POST['payment_method']) ? trim($_POST['payment_method']) : '';
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($order_id <= 0 || $client_id <= 0 || $amount <= 0) {
            $error = '请填写完整订单信息！';
        } else {
            try {
                // 获取当前订单状态
                $stmt = $pdo->prepare("SELECT status, order_no FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $current_order = $stmt->fetch();

                if (!$current_order) {
                    $error = '订单不存在！';
                } else {
                    // 检查是否可以编辑（只能编辑待支付或已支付的订单）
                    if ($current_order['status'] > 2) {
                        $error = '只能编辑待支付或已支付状态的订单！';
                    } else {
                        // 更新订单信息
                        $stmt = $pdo->prepare("UPDATE order_orders SET client_id = ?, contract_id = ?, amount = ?, status = ?, payment_method = ?, remark = ?, update_time = NOW() WHERE id = ?");
                        $result = $stmt->execute([$client_id, $contract_id, $amount, $status, $payment_method, $remark, $order_id]);

                        if ($result) {
                            record_log("编辑订单：{$current_order['order_no']}");
                            $success = '订单更新成功！';
                            // 重定向到没有参数的页面
                            header('Location: entry.php?success=edit');
                            exit;
                        } else {
                            $error = '订单更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除订单
    elseif ($_POST['action'] == 'delete') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;

        if ($order_id <= 0) {
            $error = '无效的订单ID！';
        } else {
            try {
                // 获取当前订单状态
                $stmt = $pdo->prepare("SELECT status, order_no FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $current_order = $stmt->fetch();

                if (!$current_order) {
                    $error = '订单不存在！';
                } else {
                    // 检查是否可以删除（只能删除待支付状态的订单）
                    if ($current_order['status'] != 1) {
                        $error = '只能删除待支付状态的订单！';
                    } else {
                        // 检查是否有关联的发票或退款
                        $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM order_invoices WHERE order_id = ?");
                        $stmt->execute([$order_id]);
                        $invoice_count = $stmt->fetch()['count'];

                        $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM order_refunds WHERE order_id = ?");
                        $stmt->execute([$order_id]);
                        $refund_count = $stmt->fetch()['count'];

                        if ($invoice_count > 0 || $refund_count > 0) {
                            $error = '该订单已有关联发票或退款记录，无法删除！';
                        } else {
                            // 删除订单
                            $stmt = $pdo->prepare("DELETE FROM order_orders WHERE id = ?");
                            $result = $stmt->execute([$order_id]);

                            if ($result) {
                                record_log("删除订单：{$current_order['order_no']}");
                                $success = '订单删除成功！';
                            } else {
                                $error = '订单删除失败！';
                            }
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有客户
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有有效合同
try {
    $stmt = $pdo->query("SELECT id, contract_no, client_id FROM sales_contracts WHERE status = 3 ORDER BY id DESC");
    $contracts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取合同列表失败：' . $e->getMessage();
    $contracts = [];
}

// 获取所有订单
try {
    $stmt = $pdo->query("
        SELECT o.*, c.client_name, sc.contract_no, u.username as creator_name
        FROM order_orders o
        JOIN crm_clients c ON o.client_id = c.id
        LEFT JOIN sales_contracts sc ON o.contract_id = sc.id
        JOIN sys_users u ON o.creator_id = u.id
        ORDER BY o.create_time DESC
    ");
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取订单列表失败：' . $e->getMessage();
    $orders = [];
}

// 判断是否显示表单
$show_form = false;
$edit_order = null;

// 编辑订单时显示表单并获取订单信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM order_orders WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_order = $stmt->fetch();
        if (!$edit_order) {
            $error = '订单不存在！';
            $show_form = false;
        } elseif ($edit_order['status'] > 2) {
            $error = '只能编辑待支付或已支付状态的订单！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取订单信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加订单时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '订单添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '订单更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单录入</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> &gt; 订单录入
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="entry.php?action=add" class="btn btn-add">新建订单</a>
            </div>

            <!-- 添加/编辑订单表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_order ? '编辑订单' : '新建订单'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_order ? 'edit' : 'add'; ?>">
                        <?php if ($edit_order): ?>
                            <input type="hidden" name="order_id" value="<?php echo $edit_order['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_order && $edit_order['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="contract_id">关联合同：</label>
                            <select id="contract_id" name="contract_id">
                                <option value="0">无关联合同</option>
                                <?php foreach ($contracts as $contract): ?>
                                    <option value="<?php echo $contract['id']; ?>" <?php echo ($edit_order && $edit_order['contract_id'] == $contract['id']) ? 'selected' : ''; ?> data-client="<?php echo $contract['client_id']; ?>"><?php echo htmlspecialchars($contract['contract_no']); ?></option>
                                <?php endforeach; ?>
                            </select>
                            <small>注意：只显示已生效的合同</small>
                        </div>

                        <div class="form-group">
                            <label for="amount">订单金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" value="<?php echo $edit_order ? htmlspecialchars($edit_order['amount']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="payment_method">支付方式：</label>
                            <select id="payment_method" name="payment_method">
                                <option value="">请选择支付方式</option>
                                <option value="现金" <?php echo ($edit_order && $edit_order['payment_method'] == '现金') ? 'selected' : ''; ?>>现金</option>
                                <option value="银行转账" <?php echo ($edit_order && $edit_order['payment_method'] == '银行转账') ? 'selected' : ''; ?>>银行转账</option>
                                <option value="支付宝" <?php echo ($edit_order && $edit_order['payment_method'] == '支付宝') ? 'selected' : ''; ?>>支付宝</option>
                                <option value="微信支付" <?php echo ($edit_order && $edit_order['payment_method'] == '微信支付') ? 'selected' : ''; ?>>微信支付</option>
                                <option value="其他" <?php echo ($edit_order && $edit_order['payment_method'] == '其他') ? 'selected' : ''; ?>>其他</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="status">订单状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_order && $edit_order['status'] == 1) ? 'selected' : ''; ?>>待支付</option>
                                <option value="2" <?php echo ($edit_order && $edit_order['status'] == 2) ? 'selected' : ''; ?>>已支付</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3"><?php echo $edit_order ? htmlspecialchars($edit_order['remark']) : ''; ?></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="entry.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 订单列表 -->
            <div class="table-container">
                <h3>订单列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>客户名称</th>
                            <th>关联合同</th>
                            <th>金额</th>
                            <th>支付方式</th>
                            <th>状态</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($orders)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无订单数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($orders as $order): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($order['client_name']); ?></td>
                                    <td><?php echo $order['contract_no'] ? htmlspecialchars($order['contract_no']) : '-'; ?></td>
                                    <td><?php echo number_format($order['amount'], 2); ?></td>
                                    <td><?php echo htmlspecialchars($order['payment_method'] ?: '-'); ?></td>
                                    <td>
                                        <?php
                                        if ($order['status'] == 1) echo '<span class="status-pending">待支付</span>';
                                        elseif ($order['status'] == 2) echo '<span class="status-pending">已支付</span>';
                                        elseif ($order['status'] == 3) echo '<span class="status-pending">已发货</span>';
                                        elseif ($order['status'] == 4) echo '<span class="status-active">已完成</span>';
                                        elseif ($order['status'] == 5) echo '<span class="status-inactive">已取消</span>';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($order['creator_name']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                    <td>
                                        <?php if ($order['status'] <= 2): ?>
                                            <a href="entry.php?action=edit&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <?php endif; ?>

                                        <?php if ($order['status'] == 1): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除订单 \'<?php echo htmlspecialchars($order['order_no']); ?>\' 吗？');">删除</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>