<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('performance_incentive');

// 记录访问日志
record_log('访问激励机制页面');

// 检查当前用户是否为管理员(假设角色ID=1为管理员)
$is_admin = ($_SESSION['role_id'] == 1);

// 添加激励记录
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'add' && $is_admin) {
    $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;
    $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
    $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
    $description = isset($_POST['description']) ? trim($_POST['description']) : '';
    $year = isset($_POST['year']) ? intval($_POST['year']) : date('Y');
    $month = isset($_POST['month']) ? intval($_POST['month']) : date('n');
    $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

    if ($user_id <= 0 || $amount <= 0 || empty($description)) {
        $error = '请填写有效的激励信息！';
    } else {
        try {
            // 添加激励记录
            $stmt = $pdo->prepare("INSERT INTO perf_incentives (user_id, type, amount, description, year, month, status) VALUES (?, ?, ?, ?, ?, ?, ?)");
            $result = $stmt->execute([$user_id, $type, $amount, $description, $year, $month, $status]);

            if ($result) {
                record_log("创建{$year}年{$month}月激励记录");
                $success = '激励记录创建成功！';
                header('Location: incentive.php?success=add');
                exit;
            } else {
                $error = '激励记录创建失败！';
            }
        } catch (PDOException $e) {
            $error = '系统错误：' . $e->getMessage();
        }
    }
}

// 更新激励状态
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'update' && $is_admin) {
    $incentive_id = isset($_POST['incentive_id']) ? intval($_POST['incentive_id']) : 0;
    $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

    if ($incentive_id <= 0) {
        $error = '无效的激励记录ID！';
    } else {
        try {
            $stmt = $pdo->prepare("UPDATE perf_incentives SET status = ? WHERE id = ?");
            $result = $stmt->execute([$status, $incentive_id]);

            if ($result) {
                record_log("更新激励记录状态：ID {$incentive_id}");
                $success = '激励记录状态更新成功！';
                header('Location: incentive.php?success=update');
                exit;
            } else {
                $error = '激励记录状态更新失败！';
            }
        } catch (PDOException $e) {
            $error = '系统错误：' . $e->getMessage();
        }
    }
}

// 获取筛选条件
$filter_year = isset($_GET['year']) ? intval($_GET['year']) : 0; // 0表示所有年份
$filter_month = isset($_GET['month']) ? intval($_GET['month']) : 0; // 0表示所有月份
$filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0; // 0表示所有类型
$filter_user = isset($_GET['user_id']) ? intval($_GET['user_id']) : 0; // 0表示所有用户
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0; // 0表示所有状态

// 构建查询条件
$filter_where = "";
if (!$is_admin) {
    // 非管理员只能查看自己的数据
    $filter_where = "WHERE user_id = {$_SESSION['user_id']}";
} else if ($filter_user > 0) {
    // 管理员且选择了特定用户
    $filter_where = "WHERE user_id = {$filter_user}";
} else {
    // 管理员查看所有数据
    $filter_where = "WHERE 1=1";
}

// 添加年份筛选
if ($filter_year > 0) {
    $filter_where .= " AND year = {$filter_year}";
}

// 添加月份筛选
if ($filter_month > 0) {
    $filter_where .= " AND month = {$filter_month}";
}

// 添加类型筛选
if ($filter_type > 0) {
    $filter_where .= " AND type = {$filter_type}";
}

// 添加状态筛选
if ($filter_status > 0) {
    $filter_where .= " AND status = {$filter_status}";
}

// 获取所有激励记录
try {
    $stmt = $pdo->query("
        SELECT i.*, u.username
        FROM perf_incentives i
        LEFT JOIN sys_users u ON i.user_id = u.id
        {$filter_where}
        ORDER BY i.year DESC, i.month DESC, i.id DESC
    ");
    $incentives = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取激励记录列表失败：' . $e->getMessage();
    $incentives = [];
}

// 获取所有用户列表 - 用于管理员筛选
$users_list = [];
if ($is_admin) {
    try {
        $stmt = $pdo->query("SELECT id, username FROM sys_users ORDER BY id");
        $users_list = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取用户列表失败：' . $e->getMessage();
    }
}

// 获取可选年份
$years = [];
$current_year = date('Y');
for ($i = $current_year - 2; $i <= $current_year + 1; $i++) {
    $years[] = $i;
}

// 添加激励记录时显示表单
$show_add_form = isset($_GET['action']) && $_GET['action'] == 'add' && $is_admin;

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '激励记录创建成功！';
    } elseif ($_GET['success'] == 'update') {
        $success = '激励记录状态更新成功！';
    }
}

// 计算总金额
$total_amount = 0;
foreach ($incentives as $incentive) {
    $total_amount += $incentive['amount'];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>激励机制</h2>
            <div class="breadcrumb">
                <a href="index.php">人员绩效与KPI</a> &gt; 激励机制
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 添加操作栏，放在筛选表单前面 -->
            <div class="action-bar">
                <?php if ($is_admin): ?>
                    <a href="incentive.php?action=add" class="btn btn-add">添加激励记录</a>
                <?php endif; ?>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="year">年份：</label>
                            <select id="year" name="year">
                                <option value="0">所有年份</option>
                                <?php foreach ($years as $year): ?>
                                    <option value="<?php echo $year; ?>" <?php echo $filter_year == $year ? 'selected' : ''; ?>>
                                        <?php echo $year; ?>年
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="month">月份：</label>
                            <select id="month" name="month">
                                <option value="0">全部月份</option>
                                <?php for ($i = 1; $i <= 12; $i++): ?>
                                    <option value="<?php echo $i; ?>" <?php echo $filter_month == $i ? 'selected' : ''; ?>>
                                        <?php echo $i; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="type">类型：</label>
                            <select id="type" name="type">
                                <option value="0">全部类型</option>
                                <option value="1" <?php echo $filter_type == 1 ? 'selected' : ''; ?>>提成</option>
                                <option value="2" <?php echo $filter_type == 2 ? 'selected' : ''; ?>>奖金</option>
                                <option value="3" <?php echo $filter_type == 3 ? 'selected' : ''; ?>>其他奖励</option>
                            </select>
                        </div>
                        <?php if ($is_admin): ?>
                            <div class="filter-item">
                                <label for="user_id">用户：</label>
                                <select id="user_id" name="user_id">
                                    <option value="0">全部用户</option>
                                    <?php foreach ($users_list as $user): ?>
                                        <option value="<?php echo $user['id']; ?>" <?php echo $filter_user == $user['id'] ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($user['username']); ?> (ID:<?php echo $user['id']; ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        <?php endif; ?>
                        <div class="filter-item">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="0">全部状态</option>
                                <option value="1" <?php echo $filter_status == 1 ? 'selected' : ''; ?>>待发放</option>
                                <option value="2" <?php echo $filter_status == 2 ? 'selected' : ''; ?>>已发放</option>
                            </select>
                        </div>
                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="incentive.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 添加激励记录表单 -->
            <?php if ($show_add_form): ?>
                <div class="form-container">
                    <h3>添加激励记录</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="user_id">选择用户：</label>
                            <select id="user_id" name="user_id" required>
                                <option value="">-- 请选择用户 --</option>
                                <?php foreach ($users_list as $user): ?>
                                    <option value="<?php echo $user['id']; ?>">
                                        <?php echo htmlspecialchars($user['username']); ?> (ID:<?php echo $user['id']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="type">激励类型：</label>
                            <select id="type" name="type" required>
                                <option value="1">提成</option>
                                <option value="2">奖金</option>
                                <option value="3">其他奖励</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">金额：</label>
                            <input type="number" id="amount" name="amount" min="0" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="description">说明：</label>
                            <input type="text" id="description" name="description" required>
                        </div>

                        <div class="form-group">
                            <label for="year">年份：</label>
                            <select id="year" name="year" required>
                                <?php foreach ($years as $year): ?>
                                    <option value="<?php echo $year; ?>" <?php echo $year == date('Y') ? 'selected' : ''; ?>>
                                        <?php echo $year; ?>年
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="month">月份：</label>
                            <select id="month" name="month" required>
                                <?php for ($i = 1; $i <= 12; $i++): ?>
                                    <option value="<?php echo $i; ?>" <?php echo $i == date('n') ? 'selected' : ''; ?>>
                                        <?php echo $i; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1">待发放</option>
                                <option value="2">已发放</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="incentive.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 统计信息 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>筛选结果</h3>
                    <div class="number"><?php echo count($incentives); ?></div>
                    <div class="desc">条激励记录</div>
                </div>
                <div class="dashboard-card">
                    <h3>总金额</h3>
                    <div class="number"><?php echo number_format($total_amount, 2); ?></div>
                    <div class="desc">元</div>
                </div>
            </div>

            <!-- 激励记录列表 -->
            <div class="table-container">
                <h3>激励记录列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <?php if ($is_admin || $filter_user > 0): ?>
                                <th>用户</th>
                            <?php endif; ?>
                            <th>类型</th>
                            <th>金额</th>
                            <th>说明</th>
                            <th>年月</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <?php if ($is_admin): ?>
                                <th>操作</th>
                            <?php endif; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($incentives)): ?>
                            <tr>
                                <td colspan="<?php echo $is_admin ? ($is_admin || $filter_user > 0 ? 9 : 8) : ($is_admin || $filter_user > 0 ? 8 : 7); ?>" class="text-center">暂无激励记录数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($incentives as $incentive): ?>
                                <tr>
                                    <td><?php echo $incentive['id']; ?></td>
                                    <?php if ($is_admin || $filter_user > 0): ?>
                                        <td><?php echo htmlspecialchars($incentive['username']); ?></td>
                                    <?php endif; ?>
                                    <td>
                                        <?php
                                        switch ($incentive['type']) {
                                            case 1:
                                                echo '提成';
                                                break;
                                            case 2:
                                                echo '奖金';
                                                break;
                                            case 3:
                                                echo '其他奖励';
                                                break;
                                            default:
                                                echo '未知';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo number_format($incentive['amount'], 2); ?></td>
                                    <td><?php echo htmlspecialchars($incentive['description']); ?></td>
                                    <td><?php echo $incentive['year']; ?>年<?php echo $incentive['month']; ?>月</td>
                                    <td>
                                        <?php
                                        if ($incentive['status'] == 1) {
                                            echo '<span style="color: #ffc107;">待发放</span>';
                                        } else {
                                            echo '<span style="color: #28a745;">已发放</span>';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($incentive['create_time'])); ?></td>
                                    <?php if ($is_admin): ?>
                                        <td>
                                            <?php if ($incentive['status'] == 1): ?>
                                                <form method="post" action="">
                                                    <input type="hidden" name="action" value="update">
                                                    <input type="hidden" name="incentive_id" value="<?php echo $incentive['id']; ?>">
                                                    <input type="hidden" name="status" value="2">
                                                    <button type="submit" class="btn btn-sm btn-success" onclick="return confirm('确认已发放此激励？')">标记为已发放</button>
                                                </form>
                                            <?php else: ?>
                                                <form method="post" action="">
                                                    <input type="hidden" name="action" value="update">
                                                    <input type="hidden" name="incentive_id" value="<?php echo $incentive['id']; ?>">
                                                    <input type="hidden" name="status" value="1">
                                                    <button type="submit" class="btn btn-sm btn-warning" onclick="return confirm('确认将此激励标记为待发放？')">标记为待发放</button>
                                                </form>
                                            <?php endif; ?>
                                        </td>
                                    <?php endif; ?>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 提示信息 -->
            <div class="info-box">
                <h3>关于激励机制</h3>
                <p>激励机制模块帮助您：</p>
                <ul>
                    <li><strong>提成管理</strong>：记录员工销售提成，根据业绩自动计算并管理。</li>
                    <li><strong>奖金发放</strong>：管理特别奖金、季度/年度奖励等非常规激励。</li>
                    <li><strong>发放状态追踪</strong>：清晰记录并追踪激励金额的发放状态。</li>
                    <?php if ($is_admin): ?>
                        <li><strong>一键更新状态</strong>：管理员可便捷地更新激励发放状态。</li>
                    <?php endif; ?>
                    <li><strong>历史记录查询</strong>：提供完整的历史激励记录，支持多维度筛选。</li>
                </ul>
                <p>提示：有效的激励机制是维持团队活力和促进业绩增长的重要手段，请合理配置激励策略。</p>
            </div>
        </div>
    </div>
</body>

</html>