<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('product');

// 记录访问日志
record_log('访问产品管理页面');

// 获取产品总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM product_items");
    $product_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取产品数据失败：' . $e->getMessage();
    $product_count = ['count' => 0];
}

// 获取库存统计
try {
    $stmt = $pdo->query("SELECT SUM(quantity) as total FROM product_inventory");
    $inventory_total = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取库存数据失败：' . $e->getMessage();
    $inventory_total = ['total' => 0];
}

// 获取供应商数量
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM product_suppliers WHERE status = 1");
    $supplier_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取供应商数据失败：' . $e->getMessage();
    $supplier_count = ['count' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>产品与库存管理</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <h2>产品概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>产品总数</h3>
                    <div class="number"><?php echo $product_count['count']; ?></div>
                    <div class="desc">在售产品数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>库存总量</h3>
                    <div class="number"><?php echo $inventory_total['total'] ?: 0; ?></div>
                    <div class="desc">所有产品库存总和</div>
                </div>

                <div class="dashboard-card">
                    <h3>供应商数量</h3>
                    <div class="number"><?php echo $supplier_count['count']; ?></div>
                    <div class="desc">合作中的供应商</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="catalog.php" class="function-link">
                    <h3>产品目录</h3>
                </a>
                <a href="inventory.php" class="function-link">
                    <h3>库存管理</h3>
                </a>
                <a href="supplier.php" class="function-link">
                    <h3>供应商管理</h3>
                </a>
                <a href="price.php" class="function-link">
                    <h3>价格策略</h3>
                </a>
                <a href="analysis.php" class="function-link">
                    <h3>产品销售分析</h3>
                </a>
            </div>

            <h2>最近库存操作</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>产品名称</th>
                            <th>操作类型</th>
                            <th>数量</th>
                            <th>操作人</th>
                            <th>操作时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT l.*, p.name as product_name, u.username 
                                            FROM product_stock_logs l
                                            JOIN product_items p ON l.product_id = p.id 
                                            JOIN sys_users u ON l.operator_id = u.id 
                                            ORDER BY l.create_time DESC LIMIT 5");
                            $logs = $stmt->fetchAll();

                            if (empty($logs)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无库存操作记录</td>
                                </tr>
                                <?php else:
                                foreach ($logs as $log): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($log['product_name']); ?></td>
                                        <td><?php echo $log['type'] == 1 ? '入库' : '出库'; ?></td>
                                        <td><?php echo $log['quantity']; ?></td>
                                        <td><?php echo htmlspecialchars($log['username']); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($log['create_time'])); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="5" class="text-center">获取库存操作记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>