<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('sales_chance');

// 记录访问日志
record_log('访问销售机会管理页面');

// 添加/编辑销售机会处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加销售机会
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $source = isset($_POST['source']) ? trim($_POST['source']) : '';
        $stage = isset($_POST['stage']) ? intval($_POST['stage']) : 1;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $owner_user_id = isset($_POST['owner_user_id']) ? intval($_POST['owner_user_id']) : $_SESSION['user_id'];

        if ($client_id <= 0 || empty($name)) {
            $error = '请填写完整销售机会信息！';
        } else {
            try {
                // 添加销售机会（type=2表示机会，type=1表示线索）
                $stmt = $pdo->prepare("INSERT INTO sales_leads (client_id, name, type, source, stage, amount, owner_user_id) VALUES (?, ?, 2, ?, ?, ?, ?)");
                $result = $stmt->execute([$client_id, $name, $source, $stage, $amount, $owner_user_id]);

                if ($result) {
                    record_log("添加销售机会：{$name}");
                    $success = '销售机会添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: chance.php?success=add');
                    exit;
                } else {
                    $error = '销售机会添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑销售机会
    elseif ($_POST['action'] == 'edit') {
        $lead_id = isset($_POST['lead_id']) ? intval($_POST['lead_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $source = isset($_POST['source']) ? trim($_POST['source']) : '';
        $stage = isset($_POST['stage']) ? intval($_POST['stage']) : 1;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $owner_user_id = isset($_POST['owner_user_id']) ? intval($_POST['owner_user_id']) : $_SESSION['user_id'];

        if ($lead_id <= 0 || $client_id <= 0 || empty($name)) {
            $error = '请填写完整销售机会信息！';
        } else {
            try {
                // 更新销售机会信息
                $stmt = $pdo->prepare("UPDATE sales_leads SET client_id = ?, name = ?, source = ?, stage = ?, amount = ?, owner_user_id = ? WHERE id = ? AND type = 2");
                $result = $stmt->execute([$client_id, $name, $source, $stage, $amount, $owner_user_id, $lead_id]);

                if ($result) {
                    record_log("编辑销售机会：{$name}");
                    $success = '销售机会信息更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: chance.php?success=edit');
                    exit;
                } else {
                    $error = '销售机会信息更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除销售机会
    elseif ($_POST['action'] == 'delete') {
        $lead_id = isset($_POST['lead_id']) ? intval($_POST['lead_id']) : 0;

        if ($lead_id <= 0) {
            $error = '无效的销售机会ID！';
        } else {
            try {
                // 获取销售机会名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM sales_leads WHERE id = ? AND type = 2");
                $stmt->execute([$lead_id]);
                $lead = $stmt->fetch();

                if (!$lead) {
                    $error = '销售机会不存在！';
                } else {
                    // 检查是否有关联的合同或报价单
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sales_contracts WHERE lead_id = ?");
                    $stmt->execute([$lead_id]);
                    $contract_count = $stmt->fetch()['count'];

                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sales_quotes WHERE lead_id = ?");
                    $stmt->execute([$lead_id]);
                    $quote_count = $stmt->fetch()['count'];

                    if ($contract_count > 0 || $quote_count > 0) {
                        $error = '该销售机会已关联合同或报价单，无法删除！';
                    } else {
                        // 删除销售机会
                        $stmt = $pdo->prepare("DELETE FROM sales_leads WHERE id = ? AND type = 2");
                        $result = $stmt->execute([$lead_id]);

                        if ($result) {
                            record_log("删除销售机会：{$lead['name']}");
                            $success = '销售机会删除成功！';
                        } else {
                            $error = '销售机会删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有客户
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有用户（用于选择负责人）
try {
    $stmt = $pdo->query("SELECT id, username FROM sys_users WHERE status = 1 ORDER BY id");
    $users = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户列表失败：' . $e->getMessage();
    $users = [];
}

// 获取所有销售机会
try {
    $stmt = $pdo->query("
        SELECT l.*, c.client_name, u.username as owner_name 
        FROM sales_leads l 
        JOIN crm_clients c ON l.client_id = c.id 
        LEFT JOIN sys_users u ON l.owner_user_id = u.id 
        WHERE l.type = 2 
        ORDER BY l.id DESC
    ");
    $chances = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售机会列表失败：' . $e->getMessage();
    $chances = [];
}

// 判断是否显示表单
$show_form = false;
$edit_chance = null;

// 编辑销售机会时显示表单并获取销售机会信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM sales_leads WHERE id = ? AND type = 2");
        $stmt->execute([$edit_id]);
        $edit_chance = $stmt->fetch();
        if (!$edit_chance) {
            $error = '销售机会不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取销售机会信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加销售机会时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '销售机会添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '销售机会信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售机会管理</h2>
            <div class="breadcrumb">
                <a href="index.php">销售管理</a> &gt; 销售机会管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="chance.php?action=add" class="btn btn-add">添加销售机会</a>
            </div>

            <!-- 添加/编辑销售机会表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_chance ? '编辑销售机会' : '添加销售机会'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_chance ? 'edit' : 'add'; ?>">
                        <?php if ($edit_chance): ?>
                            <input type="hidden" name="lead_id" value="<?php echo $edit_chance['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">客户名称：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_chance && $edit_chance['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="name">销售机会名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_chance ? htmlspecialchars($edit_chance['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="source">来源：</label>
                            <input type="text" id="source" name="source" value="<?php echo $edit_chance ? htmlspecialchars($edit_chance['source']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="stage">阶段：</label>
                            <select id="stage" name="stage">
                                <option value="1" <?php echo ($edit_chance && $edit_chance['stage'] == 1) ? 'selected' : ''; ?>>新建</option>
                                <option value="2" <?php echo ($edit_chance && $edit_chance['stage'] == 2) ? 'selected' : ''; ?>>跟进中</option>
                                <option value="3" <?php echo ($edit_chance && $edit_chance['stage'] == 3) ? 'selected' : ''; ?>>报价</option>
                                <option value="4" <?php echo ($edit_chance && $edit_chance['stage'] == 4) ? 'selected' : ''; ?>>赢单</option>
                                <option value="5" <?php echo ($edit_chance && $edit_chance['stage'] == 5) ? 'selected' : ''; ?>>输单</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">预计金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" value="<?php echo $edit_chance ? htmlspecialchars($edit_chance['amount']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="owner_user_id">负责人：</label>
                            <select id="owner_user_id" name="owner_user_id">
                                <?php foreach ($users as $user): ?>
                                    <option value="<?php echo $user['id']; ?>" <?php echo ($edit_chance && $edit_chance['owner_user_id'] == $user['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($user['username']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="chance.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 销售机会列表 -->
            <div class="table-container">
                <h3>销售机会列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>机会名称</th>
                            <th>客户名称</th>
                            <th>来源</th>
                            <th>阶段</th>
                            <th>预计金额</th>
                            <th>负责人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($chances)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无销售机会数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($chances as $chance): ?>
                                <tr>
                                    <td><?php echo $chance['id']; ?></td>
                                    <td><?php echo htmlspecialchars($chance['name']); ?></td>
                                    <td><?php echo htmlspecialchars($chance['client_name']); ?></td>
                                    <td><?php echo htmlspecialchars($chance['source'] ?: '-'); ?></td>
                                    <td>
                                        <?php
                                        if ($chance['stage'] == 1) echo '<span class="status-pending">新建</span>';
                                        elseif ($chance['stage'] == 2) echo '<span class="status-pending">跟进中</span>';
                                        elseif ($chance['stage'] == 3) echo '<span class="status-pending">报价</span>';
                                        elseif ($chance['stage'] == 4) echo '<span class="status-active">赢单</span>';
                                        elseif ($chance['stage'] == 5) echo '<span class="status-inactive">输单</span>';
                                        ?>
                                    </td>
                                    <td><?php echo number_format($chance['amount'], 2); ?></td>
                                    <td><?php echo htmlspecialchars($chance['owner_name']); ?></td>
                                    <td><?php echo $chance['create_time']; ?></td>
                                    <td>
                                        <a href="chance.php?action=edit&id=<?php echo $chance['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="lead_id" value="<?php echo $chance['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除销售机会 \'<?php echo htmlspecialchars($chance['name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>