<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('service');

// 记录访问日志
record_log('访问客户服务与售后页面');

// 获取工单总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM service_tickets");
    $ticket_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取工单数据失败：' . $e->getMessage();
    $ticket_count = ['count' => 0];
}

// 获取未处理工单数量
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM service_tickets WHERE status = 1");
    $pending_ticket_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取未处理工单数据失败：' . $e->getMessage();
    $pending_ticket_count = ['count' => 0];
}

// 获取客户反馈数量
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM service_feedback");
    $feedback_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取客户反馈数据失败：' . $e->getMessage();
    $feedback_count = ['count' => 0];
}

// 获取知识库文章数量
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM service_knowledge");
    $knowledge_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取知识库数据失败：' . $e->getMessage();
    $knowledge_count = ['count' => 0];
}

// 获取客户满意度平均分
try {
    $stmt = $pdo->query("SELECT AVG(score) as avg_score FROM service_satisfaction");
    $satisfaction_score = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取满意度数据失败：' . $e->getMessage();
    $satisfaction_score = ['avg_score' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客户服务与售后</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <h2>服务概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>工单总数</h3>
                    <div class="number"><?php echo $ticket_count['count']; ?></div>
                    <div class="desc">客户服务工单总量</div>
                </div>

                <div class="dashboard-card">
                    <h3>待处理工单</h3>
                    <div class="number"><?php echo $pending_ticket_count['count']; ?></div>
                    <div class="desc">需要处理的工单数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>知识库文章</h3>
                    <div class="number"><?php echo $knowledge_count['count']; ?></div>
                    <div class="desc">FAQ与帮助文档数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>客户满意度</h3>
                    <div class="number"><?php echo number_format($satisfaction_score['avg_score'] ?: 0, 1); ?></div>
                    <div class="desc">平均评分（满分5分）</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="ticket.php" class="function-link">
                    <h3>工单管理</h3>
                </a>
                <a href="feedback.php" class="function-link">
                    <h3>客户反馈管理</h3>
                </a>
                <a href="knowledge.php" class="function-link">
                    <h3>知识库</h3>
                </a>
                <a href="follow.php" class="function-link">
                    <h3>售后跟进</h3>
                </a>
                <a href="survey.php" class="function-link">
                    <h3>满意度调查</h3>
                </a>
            </div>

            <h2>最近工单</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>工单编号</th>
                            <th>客户</th>
                            <th>标题</th>
                            <th>类型</th>
                            <th>状态</th>
                            <th>处理人</th>
                            <th>创建时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT t.*, c.client_name as client_name, u.username 
                                            FROM service_tickets t
                                            JOIN crm_clients c ON t.client_id = c.id 
                                            LEFT JOIN sys_users u ON t.handler_id = u.id 
                                            ORDER BY t.create_time DESC LIMIT 5");
                            $tickets = $stmt->fetchAll();

                            if (empty($tickets)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无工单记录</td>
                                </tr>
                                <?php else:
                                foreach ($tickets as $ticket): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($ticket['ticket_no']); ?></td>
                                        <td><?php echo htmlspecialchars($ticket['client_name']); ?></td>
                                        <td><?php echo htmlspecialchars($ticket['title']); ?></td>
                                        <td>
                                            <?php
                                            if ($ticket['type'] == 1) echo '咨询';
                                            elseif ($ticket['type'] == 2) echo '投诉';
                                            elseif ($ticket['type'] == 3) echo '故障';
                                            elseif ($ticket['type'] == 4) echo '建议';
                                            else echo '其他';
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($ticket['status'] == 1) echo '<span class="status-pending">待处理</span>';
                                            elseif ($ticket['status'] == 2) echo '<span class="status-active">处理中</span>';
                                            elseif ($ticket['status'] == 3) echo '<span class="status-inactive">已完成</span>';
                                            ?>
                                        </td>
                                        <td><?php echo $ticket['handler_id'] ? htmlspecialchars($ticket['username']) : '-'; ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($ticket['create_time'])); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="7" class="text-center">获取工单记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <h2>最近反馈</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>客户</th>
                            <th>类型</th>
                            <th>反馈内容</th>
                            <th>状态</th>
                            <th>提交时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT f.*, c.client_name as client_name 
                                            FROM service_feedback f
                                            JOIN crm_clients c ON f.client_id = c.id 
                                            ORDER BY f.create_time DESC LIMIT 5");
                            $feedbacks = $stmt->fetchAll();

                            if (empty($feedbacks)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无反馈记录</td>
                                </tr>
                                <?php else:
                                foreach ($feedbacks as $feedback): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($feedback['client_name']); ?></td>
                                        <td>
                                            <?php
                                            if ($feedback['type'] == 1) echo '产品';
                                            elseif ($feedback['type'] == 2) echo '服务';
                                            elseif ($feedback['type'] == 3) echo '其他';
                                            ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($feedback['content']); ?></td>
                                        <td>
                                            <?php
                                            if ($feedback['status'] == 0) echo '<span class="status-pending">未处理</span>';
                                            elseif ($feedback['status'] == 1) echo '<span class="status-inactive">已处理</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($feedback['create_time'])); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="5" class="text-center">获取反馈记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>