<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('service_ticket');

// 记录访问日志
record_log('访问工单管理页面');

// 添加/编辑/分配工单处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加工单
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';

        if ($client_id <= 0 || empty($title) || empty($content)) {
            $error = '请填写完整工单信息！';
        } else {
            try {
                // 生成工单编号 GD-年月日-4位随机数
                $ticket_no = 'GD-' . date('Ymd') . '-' . rand(1000, 9999);

                // 添加工单
                $stmt = $pdo->prepare("INSERT INTO service_tickets (ticket_no, client_id, title, type, status) VALUES (?, ?, ?, ?, 1)");
                $result = $stmt->execute([$ticket_no, $client_id, $title, $type]);

                if ($result) {
                    record_log("添加工单：{$title}");
                    $success = '工单添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: ticket.php?success=add');
                    exit;
                } else {
                    $error = '工单添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 分配工单
    elseif ($_POST['action'] == 'assign') {
        $ticket_id = isset($_POST['ticket_id']) ? intval($_POST['ticket_id']) : 0;
        $handler_id = isset($_POST['handler_id']) ? intval($_POST['handler_id']) : 0;

        if ($ticket_id <= 0 || $handler_id <= 0) {
            $error = '请选择正确的工单和处理人！';
        } else {
            try {
                // 更新工单处理人信息并将状态改为处理中
                $stmt = $pdo->prepare("UPDATE service_tickets SET handler_id = ?, status = 2 WHERE id = ?");
                $result = $stmt->execute([$handler_id, $ticket_id]);

                if ($result) {
                    record_log("分配工单ID：{$ticket_id} 给用户ID：{$handler_id}");
                    $success = '工单分配成功！';
                    // 重定向到没有参数的页面
                    header('Location: ticket.php?success=assign');
                    exit;
                } else {
                    $error = '工单分配失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新工单状态
    elseif ($_POST['action'] == 'update_status') {
        $ticket_id = isset($_POST['ticket_id']) ? intval($_POST['ticket_id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($ticket_id <= 0 || !in_array($status, [1, 2, 3])) {
            $error = '请选择正确的工单和状态！';
        } else {
            try {
                // 更新工单状态
                $stmt = $pdo->prepare("UPDATE service_tickets SET status = ? WHERE id = ?");
                $result = $stmt->execute([$status, $ticket_id]);

                if ($result) {
                    $status_text = $status == 1 ? '待处理' : ($status == 2 ? '处理中' : '已完成');
                    record_log("更新工单ID：{$ticket_id} 状态为：{$status_text}");
                    $success = '工单状态更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: ticket.php?success=update');
                    exit;
                } else {
                    $error = '工单状态更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选参数
$status_filter = isset($_GET['status']) ? intval($_GET['status']) : 0;
$type_filter = isset($_GET['type']) ? intval($_GET['type']) : 0;

// 构建筛选条件
$where_conditions = [];
$params = [];

if ($status_filter > 0) {
    $where_conditions[] = "t.status = ?";
    $params[] = $status_filter;
}

if ($type_filter > 0) {
    $where_conditions[] = "t.type = ?";
    $params[] = $type_filter;
}

$where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

// 获取所有工单
try {
    $sql = "SELECT t.*, c.client_name as client_name, u.username 
            FROM service_tickets t
            JOIN crm_clients c ON t.client_id = c.id 
            LEFT JOIN sys_users u ON t.handler_id = u.id 
            {$where_clause}
            ORDER BY t.create_time DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $tickets = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取工单列表失败：' . $e->getMessage();
    $tickets = [];
}

// 获取所有客户，用于添加工单
try {
    $stmt = $pdo->query("SELECT id, client_name as name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有用户，用于分配工单
try {
    $stmt = $pdo->query("SELECT id, username FROM sys_users ORDER BY username");
    $users = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户列表失败：' . $e->getMessage();
    $users = [];
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '工单添加成功！';
    } elseif ($_GET['success'] == 'assign') {
        $success = '工单分配成功！';
    } elseif ($_GET['success'] == 'update') {
        $success = '工单状态更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>工单管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户服务与售后</a> &gt; 工单管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 工单状态统计 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>待处理工单</h3>
                    <div class="number">
                        <?php
                        $pending_count = 0;
                        foreach ($tickets as $ticket) {
                            if ($ticket['status'] == 1) $pending_count++;
                        }
                        echo $pending_count;
                        ?>
                    </div>
                    <div class="desc"><a href="?status=1">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>处理中工单</h3>
                    <div class="number">
                        <?php
                        $processing_count = 0;
                        foreach ($tickets as $ticket) {
                            if ($ticket['status'] == 2) $processing_count++;
                        }
                        echo $processing_count;
                        ?>
                    </div>
                    <div class="desc"><a href="?status=2">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已完成工单</h3>
                    <div class="number">
                        <?php
                        $completed_count = 0;
                        foreach ($tickets as $ticket) {
                            if ($ticket['status'] == 3) $completed_count++;
                        }
                        echo $completed_count;
                        ?>
                    </div>
                    <div class="desc"><a href="?status=3">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>工单总数</h3>
                    <div class="number"><?php echo count($tickets); ?></div>
                    <div class="desc"><a href="ticket.php">全部工单</a></div>
                </div>
            </div>

            <div class="action-bar">
                <button class="btn btn-add" onclick="toggleAddForm()">添加工单</button>
            </div>

            <!-- 添加工单表单 -->
            <div class="form-container" id="addTicketForm" style="display: none;">
                <h3>添加工单</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="client_id">选择客户：</label>
                        <select id="client_id" name="client_id" required>
                            <option value="">请选择</option>
                            <?php foreach ($clients as $client): ?>
                                <option value="<?php echo $client['id']; ?>"><?php echo htmlspecialchars($client['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="title">工单标题：</label>
                        <input type="text" id="title" name="title" required>
                    </div>

                    <div class="form-group">
                        <label for="type">工单类型：</label>
                        <select id="type" name="type">
                            <option value="1">咨询</option>
                            <option value="2">投诉</option>
                            <option value="3">故障</option>
                            <option value="4">建议</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="content">工单内容：</label>
                        <textarea id="content" name="content" rows="4" required></textarea>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">提交工单</button>
                        <button type="button" class="btn btn-secondary" onclick="toggleAddForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 工单筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="status">工单状态：</label>
                            <select id="status" name="status" onchange="this.form.submit()">
                                <option value="0">全部</option>
                                <option value="1" <?php echo $status_filter == 1 ? 'selected' : ''; ?>>待处理</option>
                                <option value="2" <?php echo $status_filter == 2 ? 'selected' : ''; ?>>处理中</option>
                                <option value="3" <?php echo $status_filter == 3 ? 'selected' : ''; ?>>已完成</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="type">工单类型：</label>
                            <select id="type" name="type" onchange="this.form.submit()">
                                <option value="0">全部</option>
                                <option value="1" <?php echo $type_filter == 1 ? 'selected' : ''; ?>>咨询</option>
                                <option value="2" <?php echo $type_filter == 2 ? 'selected' : ''; ?>>投诉</option>
                                <option value="3" <?php echo $type_filter == 3 ? 'selected' : ''; ?>>故障</option>
                                <option value="4" <?php echo $type_filter == 4 ? 'selected' : ''; ?>>建议</option>
                            </select>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 工单列表 -->
            <div class="table-container">
                <h3>工单列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>工单编号</th>
                            <th>客户</th>
                            <th>标题</th>
                            <th>类型</th>
                            <th>状态</th>
                            <th>处理人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($tickets)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无工单数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($tickets as $ticket): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($ticket['ticket_no']); ?></td>
                                    <td><?php echo htmlspecialchars($ticket['client_name']); ?></td>
                                    <td><?php echo htmlspecialchars($ticket['title']); ?></td>
                                    <td>
                                        <?php
                                        if ($ticket['type'] == 1) echo '咨询';
                                        elseif ($ticket['type'] == 2) echo '投诉';
                                        elseif ($ticket['type'] == 3) echo '故障';
                                        elseif ($ticket['type'] == 4) echo '建议';
                                        else echo '其他';
                                        ?>
                                    </td>
                                    <td>
                                        <?php
                                        if ($ticket['status'] == 1) echo '<span class="status-pending">待处理</span>';
                                        elseif ($ticket['status'] == 2) echo '<span class="status-active">处理中</span>';
                                        elseif ($ticket['status'] == 3) echo '<span class="status-inactive">已完成</span>';
                                        ?>
                                    </td>
                                    <td><?php echo $ticket['handler_id'] ? htmlspecialchars($ticket['username']) : '未分配'; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($ticket['create_time'])); ?></td>
                                    <td>
                                        <?php if ($ticket['status'] == 1): ?>
                                            <button class="btn btn-sm btn-primary" onclick="showAssignForm(<?php echo $ticket['id']; ?>)">分配</button>
                                        <?php elseif ($ticket['status'] == 2): ?>
                                            <form method="post" action="" style="display: inline;">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="ticket_id" value="<?php echo $ticket['id']; ?>">
                                                <input type="hidden" name="status" value="3">
                                                <button type="submit" class="btn btn-sm btn-success">标记完成</button>
                                            </form>
                                        <?php endif; ?>
                                        <button class="btn btn-sm btn-details" onclick="showTicketDetails(<?php echo $ticket['id']; ?>)">详情</button>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分配工单弹窗 -->
            <div id="assignModal" class="modal" style="display: none;">
                <div class="modal-content">
                    <span class="close" onclick="hideAssignForm()">&times;</span>
                    <h3>分配工单</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="assign">
                        <input type="hidden" id="assign_ticket_id" name="ticket_id" value="">

                        <div class="form-group">
                            <label for="handler_id">选择处理人：</label>
                            <select id="handler_id" name="handler_id" required>
                                <option value="">请选择</option>
                                <?php foreach ($users as $user): ?>
                                    <option value="<?php echo $user['id']; ?>"><?php echo htmlspecialchars($user['username']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">确认分配</button>
                            <button type="button" class="btn btn-secondary" onclick="hideAssignForm()">取消</button>
                        </div>
                    </form>
                </div>
            </div>

            <!-- 工单详情弹窗 -->
            <div id="detailsModal" class="modal" style="display: none;">
                <div class="modal-content">
                    <span class="close" onclick="hideTicketDetails()">&times;</span>
                    <h3>工单详情</h3>
                    <div id="ticketDetails">
                        <!-- 工单详情内容将通过JavaScript动态填充 -->
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script>
        // 显示/隐藏添加工单表单
        function toggleAddForm() {
            var form = document.getElementById('addTicketForm');
            if (form.style.display === 'none') {
                form.style.display = 'block';
            } else {
                form.style.display = 'none';
            }
        }

        // 显示分配工单弹窗
        function showAssignForm(ticketId) {
            document.getElementById('assign_ticket_id').value = ticketId;
            document.getElementById('assignModal').style.display = 'block';
        }

        // 隐藏分配工单弹窗
        function hideAssignForm() {
            document.getElementById('assignModal').style.display = 'none';
        }

        // 显示工单详情弹窗
        function showTicketDetails(ticketId) {
            // 这里应该是通过AJAX获取工单详情，但由于不希望使用JavaScript，简化处理
            var detailsHtml = '';
            <?php foreach ($tickets as $ticket): ?>
                if (<?php echo $ticket['id']; ?> === ticketId) {
                    detailsHtml = `
                        <p><strong>工单编号：</strong><?php echo htmlspecialchars($ticket['ticket_no']); ?></p>
                        <p><strong>客户：</strong><?php echo htmlspecialchars($ticket['client_name']); ?></p>
                        <p><strong>标题：</strong><?php echo htmlspecialchars($ticket['title']); ?></p>
                        <p><strong>类型：</strong>
                            <?php
                            if ($ticket['type'] == 1) echo '咨询';
                            elseif ($ticket['type'] == 2) echo '投诉';
                            elseif ($ticket['type'] == 3) echo '故障';
                            elseif ($ticket['type'] == 4) echo '建议';
                            else echo '其他';
                            ?>
                        </p>
                        <p><strong>状态：</strong>
                            <?php
                            if ($ticket['status'] == 1) echo '待处理';
                            elseif ($ticket['status'] == 2) echo '处理中';
                            elseif ($ticket['status'] == 3) echo '已完成';
                            ?>
                        </p>
                        <p><strong>处理人：</strong><?php echo $ticket['handler_id'] ? htmlspecialchars($ticket['username']) : '未分配'; ?></p>
                        <p><strong>创建时间：</strong><?php echo date('Y-m-d H:i', strtotime($ticket['create_time'])); ?></p>
                    `;
                }
            <?php endforeach; ?>

            document.getElementById('ticketDetails').innerHTML = detailsHtml;
            document.getElementById('detailsModal').style.display = 'block';
        }

        // 隐藏工单详情弹窗
        function hideTicketDetails() {
            document.getElementById('detailsModal').style.display = 'none';
        }

        // 点击模态框外部关闭模态框
        window.onclick = function(event) {
            var assignModal = document.getElementById('assignModal');
            var detailsModal = document.getElementById('detailsModal');
            if (event.target == assignModal) {
                assignModal.style.display = 'none';
            }
            if (event.target == detailsModal) {
                detailsModal.style.display = 'none';
            }
        }
    </script>

    <style>
        /* 模态框样式 */
        .modal {
            position: fixed;
            z-index: 1;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            overflow: auto;
            background-color: rgba(0, 0, 0, 0.4);
        }

        .modal-content {
            background-color: #fefefe;
            margin: 15% auto;
            padding: 20px;
            border: 1px solid #888;
            width: 50%;
            border-radius: 4px;
        }

        .close {
            color: #aaa;
            float: right;
            font-size: 28px;
            font-weight: bold;
            cursor: pointer;
        }

        .close:hover,
        .close:focus {
            color: black;
            text-decoration: none;
        }

        /* 表单内文本框样式 */
        textarea {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
            resize: vertical;
        }

        /* 内联表单 */
        .inline-form {
            display: inline;
        }
    </style>
</body>

</html>