<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('system_role');

// 记录访问日志
record_log('访问角色权限管理页面');

// 定义系统所有可用权限
$all_permissions = [
    'system' => [
        'view' => '系统设置-查看',
        'user' => '系统设置-用户管理',
        'role' => '系统设置-角色管理',
        'log' => '系统设置-日志查看',
        'backup' => '系统设置-数据备份'
    ],
    'client' => [
        'view' => '客户管理-查看',
        'add' => '客户管理-添加',
        'edit' => '客户管理-编辑',
        'delete' => '客户管理-删除',
        'classify' => '客户管理-客户分类',
        'vip' => '客户管理-VIP管理'
    ],
    'contact' => [
        'view' => '联系人管理-查看',
        'add' => '联系人管理-添加',
        'edit' => '联系人管理-编辑',
        'delete' => '联系人管理-删除'
    ],
    'sales' => [
        'view' => '销售管理-查看',
        'chance' => '销售管理-销售机会',
        'clue' => '销售管理-销售线索',
        'track' => '销售管理-销售过程',
        'performance' => '销售管理-业绩查看'
    ],
    'contract' => [
        'view' => '合同管理-查看',
        'add' => '合同管理-添加',
        'edit' => '合同管理-编辑',
        'delete' => '合同管理-删除',
        'approve' => '合同管理-审批流程',
        'template' => '合同管理-合同模板'
    ],
    'order' => [
        'view' => '订单管理-查看',
        'add' => '订单管理-添加',
        'edit' => '订单管理-编辑',
        'delete' => '订单管理-删除',
        'approve' => '订单管理-订单审核',
        'status' => '订单管理-状态管理',
        'invoice' => '订单管理-发票管理',
        'refund' => '订单管理-退款退货'
    ],
    'marketing' => [
        'view' => '市场营销-查看',
        'activity' => '市场营销-活动管理',
        'email' => '市场营销-邮件营销',
        'sms' => '市场营销-短信营销',
        'ad' => '市场营销-广告投放',
        'analysis' => '市场营销-营销分析'
    ],
    'service' => [
        'view' => '客户服务-查看',
        'ticket' => '客户服务-工单管理',
        'feedback' => '客户服务-反馈管理',
        'knowledge' => '客户服务-知识库',
        'follow' => '客户服务-售后跟进',
        'survey' => '客户服务-满意度调查'
    ],
    'product' => [
        'view' => '产品管理-查看',
        'add' => '产品管理-添加',
        'edit' => '产品管理-编辑',
        'delete' => '产品管理-删除',
        'inventory' => '产品管理-库存管理',
        'supplier' => '产品管理-供应商管理',
        'price' => '产品管理-价格策略',
        'analysis' => '产品管理-销售分析'
    ],
    'finance' => [
        'view' => '财务管理-查看',
        'receipt' => '财务管理-收款管理',
        'payment' => '财务管理-付款审核',
        'commission' => '财务管理-佣金管理',
        'budget' => '财务管理-预算成本',
        'reconcile' => '财务管理-对账管理'
    ],
    'report' => [
        'view' => '数据分析-查看',
        'client' => '数据分析-客户分析',
        'sales' => '数据分析-销售分析',
        'marketing' => '数据分析-营销分析',
        'service' => '数据分析-客服分析',
        'finance' => '数据分析-财务分析',
        'custom' => '数据分析-自定义报表'
    ],
    'task' => [
        'view' => '任务日程-查看',
        'add' => '任务日程-添加',
        'edit' => '任务日程-编辑',
        'delete' => '任务日程-删除',
        'calendar' => '任务日程-日程安排',
        'notify' => '任务日程-提醒通知',
        'team' => '任务日程-团队协作'
    ],
    'performance' => [
        'view' => '绩效管理-查看',
        'target' => '绩效管理-目标设定',
        'assess' => '绩效管理-业绩考核',
        'incentive' => '绩效管理-激励机制'
    ],
    'profile' => [
        'view' => '个人信息-查看',
        'edit' => '个人信息-编辑'
    ]
];

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加角色
    if ($_POST['action'] == 'add') {
        $role_name = isset($_POST['role_name']) ? trim($_POST['role_name']) : '';
        $permissions = isset($_POST['permissions']) ? $_POST['permissions'] : [];

        if (empty($role_name)) {
            $error = '角色名称不能为空！';
        } else {
            try {
                // 检查角色名是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sys_roles WHERE role_name = ?");
                $stmt->execute([$role_name]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '角色名称已存在！';
                } else {
                    // 权限处理
                    $permissions_json = json_encode(process_permissions($permissions));

                    // 添加角色
                    $stmt = $pdo->prepare("INSERT INTO sys_roles (role_name, permissions) VALUES (?, ?)");
                    $result = $stmt->execute([$role_name, $permissions_json]);

                    if ($result) {
                        record_log("添加角色：{$role_name}");
                        $success = '角色添加成功！';
                    } else {
                        $error = '角色添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
    // 编辑角色
    elseif ($_POST['action'] == 'edit') {
        $role_id = isset($_POST['role_id']) ? intval($_POST['role_id']) : 0;
        $role_name = isset($_POST['role_name']) ? trim($_POST['role_name']) : '';
        $permissions = isset($_POST['permissions']) ? $_POST['permissions'] : [];

        if ($role_id <= 0 || empty($role_name)) {
            $error = '请填写完整角色信息！';
        } else {
            try {
                // 检查角色名是否已被其他角色使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sys_roles WHERE role_name = ? AND id != ?");
                $stmt->execute([$role_name, $role_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '角色名称已被其他角色使用！';
                } else {
                    // 权限处理
                    $permissions_json = json_encode(process_permissions($permissions));

                    // 更新角色
                    $stmt = $pdo->prepare("UPDATE sys_roles SET role_name = ?, permissions = ? WHERE id = ?");
                    $result = $stmt->execute([$role_name, $permissions_json, $role_id]);

                    if ($result) {
                        record_log("编辑角色：{$role_name}");
                        $success = '角色更新成功！';
                    } else {
                        $error = '角色更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
    // 删除角色
    elseif ($_POST['action'] == 'delete') {
        $role_id = isset($_POST['role_id']) ? intval($_POST['role_id']) : 0;

        if ($role_id <= 0) {
            $error = '无效的角色ID！';
        } elseif ($role_id == 1) {
            $error = '系统管理员角色不能删除！';
        } else {
            try {
                // 检查是否有用户使用此角色
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sys_users WHERE role_id = ?");
                $stmt->execute([$role_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '此角色下有用户，不能删除！';
                } else {
                    // 获取角色名，用于日志记录
                    $stmt = $pdo->prepare("SELECT role_name FROM sys_roles WHERE id = ?");
                    $stmt->execute([$role_id]);
                    $role = $stmt->fetch();

                    if (!$role) {
                        $error = '角色不存在！';
                    } else {
                        // 删除角色
                        $stmt = $pdo->prepare("DELETE FROM sys_roles WHERE id = ?");
                        $result = $stmt->execute([$role_id]);

                        if ($result) {
                            record_log("删除角色：{$role['role_name']}");
                            $success = '角色删除成功！';
                        } else {
                            $error = '角色删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 处理权限数据结构
function process_permissions($permissions)
{
    $result = [];

    // 如果有all权限，直接返回
    if (isset($permissions['all'])) {
        $result['all'] = true;
        return $result;
    }

    // 处理一级权限
    foreach ($permissions as $key => $value) {
        // 键名中包含点号的是子权限
        if (strpos($key, '.') !== false) {
            list($parent, $child) = explode('.', $key);

            // 初始化父权限数组（如果还没有）
            if (!isset($result[$parent]) || !is_array($result[$parent])) {
                $result[$parent] = [];
            }

            // 设置子权限
            $result[$parent][$child] = true;
        } else {
            // 设置父权限
            $result[$key] = true;
        }
    }

    return $result;
}

// 获取所有角色
try {
    $stmt = $pdo->query("SELECT * FROM sys_roles ORDER BY id");
    $roles = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取角色列表失败：' . $e->getMessage();
    $roles = [];
}

// 权限列表
$permission_list = [
    'system' => '系统设置',
    'system.view' => '查看系统设置',
    'system.user' => '用户管理',
    'system.role' => '角色管理',
    'system.log' => '日志管理',
    'system.backup' => '数据备份',

    'client' => '客户管理',
    'client.view' => '查看客户',
    'client.add' => '添加客户',
    'client.edit' => '编辑客户',
    'client.delete' => '删除客户',
    'client.classify' => '客户分类',
    'client.vip' => 'VIP管理',

    'contact' => '联系人管理',
    'contact.view' => '查看联系人',
    'contact.add' => '添加联系人',
    'contact.edit' => '编辑联系人',
    'contact.delete' => '删除联系人',

    'sales' => '销售管理',
    'sales.view' => '查看销售',
    'sales.chance' => '销售机会',
    'sales.clue' => '销售线索',
    'sales.track' => '销售过程',
    'sales.performance' => '业绩查看',

    'contract' => '合同管理',
    'contract.view' => '查看合同',
    'contract.add' => '添加合同',
    'contract.edit' => '编辑合同',
    'contract.delete' => '删除合同',
    'contract.approve' => '审批流程',
    'contract.template' => '合同模板',

    'order' => '订单管理',
    'order.view' => '查看订单',
    'order.add' => '添加订单',
    'order.edit' => '编辑订单',
    'order.delete' => '删除订单',
    'order.approve' => '订单审核',
    'order.status' => '状态管理',
    'order.invoice' => '发票管理',
    'order.refund' => '退款退货',

    'marketing' => '市场营销',
    'marketing.view' => '查看营销',
    'marketing.activity' => '活动管理',
    'marketing.email' => '邮件营销',
    'marketing.sms' => '短信营销',
    'marketing.ad' => '广告投放',
    'marketing.analysis' => '营销分析',

    'service' => '客户服务',
    'service.view' => '查看客服',
    'service.ticket' => '工单管理',
    'service.feedback' => '反馈管理',
    'service.knowledge' => '知识库',
    'service.follow' => '售后跟进',
    'service.survey' => '满意度调查',

    'product' => '产品管理',
    'product.view' => '查看产品',
    'product.add' => '添加产品',
    'product.edit' => '编辑产品',
    'product.delete' => '删除产品',
    'product.inventory' => '库存管理',
    'product.supplier' => '供应商管理',
    'product.price' => '价格策略',
    'product.analysis' => '销售分析',

    'finance' => '财务管理',
    'finance.view' => '查看财务',
    'finance.receipt' => '收款管理',
    'finance.payment' => '付款审核',
    'finance.commission' => '佣金管理',
    'finance.budget' => '预算成本',
    'finance.reconcile' => '对账管理',

    'report' => '数据分析',
    'report.view' => '查看数据分析',
    'report.client' => '客户分析',
    'report.sales' => '销售分析',
    'report.marketing' => '营销分析',
    'report.service' => '客服分析',
    'report.finance' => '财务分析',
    'report.custom' => '自定义报表',

    'task' => '任务日程',
    'task.view' => '查看任务',
    'task.add' => '添加任务',
    'task.edit' => '编辑任务',
    'task.delete' => '删除任务',
    'task.calendar' => '日程安排',
    'task.notify' => '提醒通知',
    'task.team' => '团队协作',

    'performance' => '绩效管理',
    'performance.view' => '查看绩效',
    'performance.target' => '目标设定',
    'performance.assess' => '业绩考核',
    'performance.incentive' => '激励机制',

    'profile' => '个人信息',
    'profile.view' => '查看个人信息',
    'profile.edit' => '编辑个人信息',

    'all' => '所有权限'
];

// 分组权限，便于前端展示
$permission_groups = [
    '系统设置' => ['system', 'system.view', 'system.user', 'system.role', 'system.log', 'system.backup'],
    '客户管理' => ['client', 'client.view', 'client.add', 'client.edit', 'client.delete', 'client.classify', 'client.vip'],
    '联系人管理' => ['contact', 'contact.view', 'contact.add', 'contact.edit', 'contact.delete'],
    '销售管理' => ['sales', 'sales.view', 'sales.chance', 'sales.clue', 'sales.track', 'sales.performance'],
    '合同管理' => ['contract', 'contract.view', 'contract.add', 'contract.edit', 'contract.delete', 'contract.approve', 'contract.template'],
    '订单管理' => ['order', 'order.view', 'order.add', 'order.edit', 'order.delete', 'order.approve', 'order.status', 'order.invoice', 'order.refund'],
    '市场营销' => ['marketing', 'marketing.view', 'marketing.activity', 'marketing.email', 'marketing.sms', 'marketing.ad', 'marketing.analysis'],
    '客户服务' => ['service', 'service.view', 'service.ticket', 'service.feedback', 'service.knowledge', 'service.follow', 'service.survey'],
    '产品管理' => ['product', 'product.view', 'product.add', 'product.edit', 'product.delete', 'product.inventory', 'product.supplier', 'product.price', 'product.analysis'],
    '财务管理' => ['finance', 'finance.view', 'finance.receipt', 'finance.payment', 'finance.commission', 'finance.budget', 'finance.reconcile'],
    '数据分析' => ['report', 'report.view', 'report.client', 'report.sales', 'report.marketing', 'report.service', 'report.finance', 'report.custom'],
    '任务日程' => ['task', 'task.view', 'task.add', 'task.edit', 'task.delete', 'task.calendar', 'task.notify', 'task.team'],
    '绩效管理' => ['performance', 'performance.view', 'performance.target', 'performance.assess', 'performance.incentive'],
    '个人信息' => ['profile', 'profile.view', 'profile.edit'],
    '特殊权限' => ['all']
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>角色权限管理</h2>
            <div class="breadcrumb">
                <a href="index.php">系统设置</a> &gt; 角色权限管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <button class="btn btn-primary" onclick="showAddForm()">添加角色</button>
            </div>

            <!-- 添加角色表单 -->
            <div id="addRoleForm" class="form-container" style="display: none;">
                <h3>添加角色</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="role_name">角色名称：</label>
                        <input type="text" id="role_name" name="role_name" required>
                    </div>

                    <div class="form-group">
                        <label>权限设置：</label>
                        <div class="options-container">
                            <?php foreach ($permission_groups as $group => $permissions): ?>
                                <div class="option-group">
                                    <h4 class="group-header"><?php echo $group; ?></h4>
                                    <?php foreach ($permissions as $permission): ?>
                                        <div class="checkbox-item">
                                            <label>
                                                <input type="checkbox" name="permissions[<?php echo $permission; ?>]" value="1" <?php echo $permission == 'all' ? 'onclick="toggleAllPermissions(this)"' : ''; ?>>
                                                <?php echo $permission_list[$permission]; ?>
                                            </label>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideAddForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 编辑角色表单 -->
            <div id="editRoleForm" class="form-container" style="display: none;">
                <h3>编辑角色</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="edit">
                    <input type="hidden" name="role_id" id="edit_role_id">

                    <div class="form-group">
                        <label for="edit_role_name">角色名称：</label>
                        <input type="text" id="edit_role_name" name="role_name" required>
                    </div>

                    <div class="form-group">
                        <label>权限设置：</label>
                        <div class="options-container" id="edit_permissions_container">
                            <?php foreach ($permission_groups as $group => $permissions): ?>
                                <div class="option-group">
                                    <h4 class="group-header"><?php echo $group; ?></h4>
                                    <?php foreach ($permissions as $permission): ?>
                                        <div class="checkbox-item">
                                            <label>
                                                <input type="checkbox" name="permissions[<?php echo $permission; ?>]" value="1" id="edit_perm_<?php echo str_replace('.', '_', $permission); ?>" <?php echo $permission == 'all' ? 'onclick="toggleAllPermissionsEdit(this)"' : ''; ?>>
                                                <?php echo $permission_list[$permission]; ?>
                                            </label>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideEditForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 角色列表 -->
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>角色名称</th>
                            <th>权限数量</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($roles)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无角色数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($roles as $role): ?>
                                <?php
                                $permissions = !empty($role['permissions']) ? json_decode($role['permissions'], true) : [];
                                $permissionCount = 0;

                                if (!empty($permissions)) {
                                    if (isset($permissions['all']) && $permissions['all'] === true) {
                                        $permissionCount = '全部权限';
                                    } else {
                                        // 计算权限数量
                                        foreach ($permissions as $key => $value) {
                                            if (is_array($value)) {
                                                $permissionCount += count($value);
                                            } else {
                                                $permissionCount++;
                                            }
                                        }
                                    }
                                }
                                ?>
                                <tr>
                                    <td><?php echo $role['id']; ?></td>
                                    <td><?php echo htmlspecialchars($role['role_name']); ?></td>
                                    <td><?php echo $permissionCount; ?></td>
                                    <td><?php echo $role['create_time']; ?></td>
                                    <td>
                                        <button class="btn btn-sm btn-primary" onclick="editRole(<?php echo $role['id']; ?>, '<?php echo htmlspecialchars($role['role_name']); ?>', <?php echo htmlspecialchars(json_encode($permissions)); ?>)">编辑</button>
                                        <?php if ($role['id'] != 1): // 防止删除超级管理员角色 
                                        ?>
                                            <button class="btn btn-sm btn-danger" onclick="deleteRole(<?php echo $role['id']; ?>, '<?php echo htmlspecialchars($role['role_name']); ?>')">删除</button>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 删除角色表单 -->
            <form id="deleteRoleForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="delete">
                <input type="hidden" name="role_id" id="delete_role_id">
            </form>
        </div>
    </div>

    <script>
        // 显示添加角色表单
        function showAddForm() {
            document.getElementById('addRoleForm').style.display = 'block';
        }

        // 隐藏添加角色表单
        function hideAddForm() {
            document.getElementById('addRoleForm').style.display = 'none';
        }

        // 显示编辑角色表单
        function editRole(id, roleName, permissions) {
            document.getElementById('edit_role_id').value = id;
            document.getElementById('edit_role_name').value = roleName;

            // 重置所有权限
            var checkboxes = document.querySelectorAll('#edit_permissions_container input[type="checkbox"]');
            checkboxes.forEach(function(checkbox) {
                checkbox.checked = false;
            });

            // 设置已有权限
            if (permissions) {
                // 处理all权限
                if (permissions.all) {
                    document.getElementById('edit_perm_all').checked = true;
                    // 选中所有权限
                    checkboxes.forEach(function(checkbox) {
                        checkbox.checked = true;
                    });
                } else {
                    // 处理一级权限
                    for (var key in permissions) {
                        if (permissions.hasOwnProperty(key)) {
                            var value = permissions[key];

                            if (typeof value === 'boolean' && value) {
                                var checkbox = document.getElementById('edit_perm_' + key);
                                if (checkbox) {
                                    checkbox.checked = true;
                                }
                            } else if (typeof value === 'object') {
                                // 处理二级权限
                                for (var subKey in value) {
                                    if (value.hasOwnProperty(subKey) && value[subKey]) {
                                        var checkbox = document.getElementById('edit_perm_' + key + '_' + subKey);
                                        if (checkbox) {
                                            checkbox.checked = true;
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }

            document.getElementById('editRoleForm').style.display = 'block';
        }

        // 隐藏编辑角色表单
        function hideEditForm() {
            document.getElementById('editRoleForm').style.display = 'none';
        }

        // 删除角色确认
        function deleteRole(id, roleName) {
            if (confirm('确定要删除角色 "' + roleName + '" 吗？')) {
                document.getElementById('delete_role_id').value = id;
                document.getElementById('deleteRoleForm').submit();
            }
        }

        // 选中"所有权限"时，自动选中所有权限
        function toggleAllPermissions(checkbox) {
            var checkboxes = document.querySelectorAll('#addRoleForm input[type="checkbox"]');
            checkboxes.forEach(function(item) {
                item.checked = checkbox.checked;
            });
        }

        // 编辑表单中的全选功能
        function toggleAllPermissionsEdit(checkbox) {
            var checkboxes = document.querySelectorAll('#editRoleForm input[type="checkbox"]');
            checkboxes.forEach(function(item) {
                item.checked = checkbox.checked;
            });
        }
    </script>
</body>

</html>